# encoding: UTF-8

# This is the main file that implements the sniffer tool.
#
# If you modify this example extension, you should change the
# top level namespace module name to your unique namespace.
# Also then add your copyright notice to the comments at the
# top of the extension registrar file.

module BradenYork # <-- the top level namespace module
  module FaceSniffer # extension submodule

    class FaceSnifferTool

      CURSOR ||= UI.create_cursor(
        Sketchup.find_support_file('cursor_select.svg', 'Images'),
        0, 0
      )

      def initialize
        @selset = Sketchup.active_model.selection
      end

      def activate
        Sketchup.set_status_text(
          'Select faces to see their area in Entity Info'
        )
      end

      def deactivate(view)
        @selset.clear
        Sketchup.set_status_text("")
      end

      def onSetCursor
        UI.set_cursor(CURSOR)
      end

       def onLButtonUp(flags, x, y, view)
        ph  = view.pick_helper
        num = ph.do_pick(x,y)
        #puts "items picked = #{num}"
        return unless num > 0
        # Note: Selection #add, #remove, and #toggle are method aliases.
        if pressed_shift_and_control(flags) # remove
          #puts "SHIFT + CTRL is pressed"
          @selset.remove(ph.picked_face) if @selset.contains?(ph.picked_face)
        elsif pressed_shift(flags) # toggle
          #puts "SHIFT is pressed"
          @selset.toggle(ph.picked_face)
        elsif pressed_control(flags) # add
          #puts "CTRL is pressed"
          @selset.add(ph.picked_face) unless @selset.contains?(ph.picked_face)
        else # clear and add
          #puts "No modifiers pressed"
          @selset.clear
          @selset.add(ph.picked_face)
        end
      end

      def pressed_control(flags)
        (flags & COPY_MODIFIER_MASK) == COPY_MODIFIER_MASK
      end

      def pressed_shift(flags)
        (flags & CONSTRAIN_MODIFIER_MASK) == CONSTRAIN_MODIFIER_MASK
      end

      def pressed_shift_and_control(flags)
        shift(flags) && control(flags)
      end

    end # tool class

    if !defined?(@loaded)
      @loaded = true
      CMD = UI::Command.new('Face Sniffer') {
        FaceSnifferTool.activate
      }
      CMD.status_bar_text = "Pick Nested Faces to see Area"
      UI.menu('Tools').add_item(CMD)
    end

  end # extension submodule
end # namespace module